export declare const schema: {
    "$schema": string;
    "definitions": {
        "Comparable": {
            "type": string[];
        };
        "Equatable": {
            "type": string[];
        };
        "Serializable": {
            "anyOf": ({
                "type": string;
                "properties": {};
                "items"?: undefined;
            } | {
                "type": string;
                "items": {};
                "properties"?: undefined;
            } | {
                "type": string[];
                "properties"?: undefined;
                "items"?: undefined;
            })[];
        };
        "Document": {
            "type": string;
            "properties": {
                "key": {
                    "type": string;
                };
                "value": {
                    "anyOf": ({
                        "type": string;
                        "properties": {};
                        "items"?: undefined;
                    } | {
                        "type": string;
                        "items": {};
                        "properties"?: undefined;
                    } | {
                        "type": string[];
                        "properties"?: undefined;
                        "items"?: undefined;
                    })[];
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "PathFilter": {
            "type": string;
            "properties": {
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "EqFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "NeFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "ComparableFilter": {
            "type": string;
            "properties": {
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "GtFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "GteFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "LtFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "LteFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "ExistsFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "IsNullFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "MatchesFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "pattern": {
                    "type": string;
                };
                "caseInsensitive": {
                    "type": string;
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "StartsWithFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "value": {
                    "type": string;
                };
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "AndFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "filters": {
                    "type": string;
                    "items": {
                        "anyOf": {
                            "$ref": string;
                        }[];
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "OrFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "filters": {
                    "type": string;
                    "items": {
                        "anyOf": {
                            "$ref": string;
                        }[];
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "NotFilter": {
            "type": string;
            "properties": {
                "operator": {
                    "type": string;
                    "enum": string[];
                };
                "filter": {
                    "anyOf": {
                        "$ref": string;
                    }[];
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "Filter": {
            "anyOf": {
                "$ref": string;
            }[];
        };
        "Direction": {
            "enum": string[];
            "type": string;
        };
        "Order": {
            "type": string;
            "properties": {
                "path": {
                    "type": string;
                    "items": {
                        "type": string;
                    };
                };
                "direction": {
                    "$ref": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "Query": {
            "type": string;
            "properties": {
                "filter": {
                    "anyOf": {
                        "$ref": string;
                    }[];
                };
                "limit": {
                    "type": string;
                };
                "skip": {
                    "type": string;
                };
                "orderBy": {
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "ClientContext": {
            "type": string;
            "properties": {
                "appId": {
                    "type": string;
                };
                "appEnv": {
                    "type": string;
                };
                "collection": {
                    "type": string;
                };
                "auth": {
                    "type": string;
                    "properties": {
                        "v1": {
                            "type": string;
                            "properties": {
                                "token": {
                                    "type": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                    };
                    "propertyOrder": string[];
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "ServerOnlyContext": {
            "type": string;
            "properties": {
                "verifiedToken": {
                    "type": string;
                    "properties": {};
                    "additionalProperties": boolean;
                };
                "tags": {
                    "type": string;
                    "additionalProperties": {
                        "type": string;
                    };
                    "propertyOrder": never[];
                };
                "logLevel": {
                    "type": string;
                };
                "logExtra": {
                    "type": string;
                    "additionalProperties": {};
                    "propertyOrder": never[];
                };
                "sampleRate": {
                    "type": string;
                };
                "debugId": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "UpdateOptions": {
            "type": string;
            "properties": {
                "operationId": {
                    "description": string;
                    "type": string;
                };
            };
            "propertyOrder": string[];
        };
        "Version": {
            "type": string;
            "properties": {
                "major": {
                    "type": string;
                };
                "minor": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "Patch": {
            "type": string;
            "properties": {
                "version": {
                    "$ref": string;
                };
                "operationId": {
                    "description": string;
                    "type": string;
                };
                "ops": {
                    "type": string;
                    "items": {
                        "anyOf": {
                            "$ref": string;
                        }[];
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "KeyedPatches": {
            "type": string;
            "items": {
                "type": string;
                "items": ({
                    "type": string;
                    "items"?: undefined;
                } | {
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                })[];
                "minItems": number;
                "additionalItems": {
                    "anyOf": ({
                        "type": string;
                        "items"?: undefined;
                    } | {
                        "type": string;
                        "items": {
                            "$ref": string;
                        };
                    })[];
                };
            };
        };
        "VersionedObject": {
            "type": string;
            "properties": {
                "version": {
                    "$ref": string;
                };
                "value": {
                    "anyOf": ({
                        "type": string;
                        "properties": {};
                        "items"?: undefined;
                    } | {
                        "type": string;
                        "items": {};
                        "properties"?: undefined;
                    } | {
                        "type": string[];
                        "properties"?: undefined;
                        "items"?: undefined;
                    })[];
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "VersionedMaybeObject": {
            "type": string;
            "properties": {
                "version": {
                    "$ref": string;
                };
                "value": {
                    "anyOf": ({
                        "type": string;
                        "properties": {};
                        "items"?: undefined;
                    } | {
                        "type": string;
                        "items": {};
                        "properties"?: undefined;
                    } | {
                        "type": string[];
                        "properties"?: undefined;
                        "items"?: undefined;
                    })[];
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "Patches": {
            "type": string;
            "properties": {
                "patches": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "KeyedVersions": {
            "type": string;
            "items": {
                "type": string;
                "items": ({
                    "type": string;
                    "$ref"?: undefined;
                } | {
                    "$ref": string;
                    "type"?: undefined;
                })[];
                "minItems": number;
                "additionalItems": {
                    "anyOf": ({
                        "type": string;
                        "$ref"?: undefined;
                    } | {
                        "$ref": string;
                        "type"?: undefined;
                    })[];
                };
            };
        };
        "StoredDocument": {
            "type": string;
            "properties": {
                "updatedAt": {
                    "type": string;
                };
                "version": {
                    "$ref": string;
                };
                "value": {
                    "anyOf": ({
                        "type": string;
                        "properties": {};
                        "items"?: undefined;
                    } | {
                        "type": string;
                        "items": {};
                        "properties"?: undefined;
                    } | {
                        "type": string[];
                        "properties"?: undefined;
                        "items"?: undefined;
                    })[];
                };
                "patches": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "PollOptions": {
            "type": string;
            "properties": {
                "readBlockTimeMs": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
        };
        "Tombstone": {
            "description": string;
            "type": string;
            "properties": {
                "updatedAt": {
                    "type": string;
                };
                "version": {
                    "$ref": string;
                };
                "patches": {
                    "description": string;
                    "type": string;
                    "items": {
                        "$ref": string;
                    };
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "DB": {
            "type": string;
            "properties": {
                "get": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "key": {
                                    "type": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {};
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "getWithVersion": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "key": {
                                    "type": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "$ref": string;
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "setIfVersion": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "key": {
                                    "type": string;
                                };
                                "version": {
                                    "$ref": string;
                                };
                                "value": {
                                    "anyOf": ({
                                        "type": string;
                                        "properties": {};
                                        "items"?: undefined;
                                    } | {
                                        "type": string;
                                        "items": {};
                                        "properties"?: undefined;
                                    } | {
                                        "type": string[];
                                        "properties"?: undefined;
                                        "items"?: undefined;
                                    })[];
                                };
                                "opts": {
                                    "$ref": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "type": string;
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "startPolling": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "key": {
                                    "type": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "$ref": string;
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "poll": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "keysToVersions": {
                                    "type": string;
                                    "items": {
                                        "type": string;
                                        "items": ({
                                            "type": string;
                                            "$ref"?: undefined;
                                        } | {
                                            "$ref": string;
                                            "type"?: undefined;
                                        })[];
                                        "minItems": number;
                                        "additionalItems": {
                                            "anyOf": ({
                                                "type": string;
                                                "$ref"?: undefined;
                                            } | {
                                                "$ref": string;
                                                "type"?: undefined;
                                            })[];
                                        };
                                    };
                                };
                                "opts": {
                                    "$ref": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "type": string;
                            "items": {
                                "type": string;
                                "items": ({
                                    "type": string;
                                    "items"?: undefined;
                                } | {
                                    "type": string;
                                    "items": {
                                        "$ref": string;
                                    };
                                })[];
                                "minItems": number;
                                "additionalItems": {
                                    "anyOf": ({
                                        "type": string;
                                        "items"?: undefined;
                                    } | {
                                        "type": string;
                                        "items": {
                                            "$ref": string;
                                        };
                                    })[];
                                };
                            };
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "create": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "key": {
                                    "type": string;
                                };
                                "value": {
                                    "anyOf": ({
                                        "type": string;
                                        "properties": {};
                                        "items"?: undefined;
                                    } | {
                                        "type": string;
                                        "items": {};
                                        "properties"?: undefined;
                                    } | {
                                        "type": string[];
                                        "properties"?: undefined;
                                        "items"?: undefined;
                                    })[];
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "type": string;
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "remove": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "key": {
                                    "type": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "type": string;
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
                "find": {
                    "description": string;
                    "type": string;
                    "properties": {
                        "params": {
                            "type": string;
                            "properties": {
                                "query": {
                                    "$ref": string;
                                };
                            };
                            "propertyOrder": string[];
                            "required": string[];
                        };
                        "returns": {
                            "type": string;
                            "items": {
                                "$ref": string;
                            };
                        };
                    };
                    "propertyOrder": string[];
                    "required": string[];
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "AddOperation<any>": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "value": {};
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "RemoveOperation": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "ReplaceOperation<any>": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "value": {};
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "MoveOperation": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "from": {
                    "type": string;
                };
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "CopyOperation": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "from": {
                    "type": string;
                };
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "TestOperation<any>": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "value": {};
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
        "GetOperation<any>": {
            "type": string;
            "properties": {
                "op": {
                    "type": string;
                    "enum": string[];
                };
                "value": {};
                "path": {
                    "type": string;
                };
            };
            "propertyOrder": string[];
            "required": string[];
        };
    };
};
export declare class InternalServerError extends Error {
    readonly name = "InternalServerError";
}
export declare enum Direction {
    ASC = "ASC",
    DESC = "DESC"
}
export declare type Serializable = ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean));
export declare type Filter = (EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter);
export interface Document {
    readonly key: string;
    readonly value: ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean));
}
export interface PathFilter {
    readonly path: Array<string>;
}
export interface EqFilter {
    readonly operator: "eq";
    readonly value: (string) | (number) | (boolean);
    readonly path: Array<string>;
}
export interface NeFilter {
    readonly operator: "ne";
    readonly value: (string) | (number) | (boolean);
    readonly path: Array<string>;
}
export interface ComparableFilter {
    readonly value: (string) | (number);
    readonly path: Array<string>;
}
export interface GtFilter {
    readonly operator: "gt";
    readonly value: (string) | (number);
    readonly path: Array<string>;
}
export interface GteFilter {
    readonly operator: "gte";
    readonly value: (string) | (number);
    readonly path: Array<string>;
}
export interface LtFilter {
    readonly operator: "lt";
    readonly value: (string) | (number);
    readonly path: Array<string>;
}
export interface LteFilter {
    readonly operator: "lte";
    readonly value: (string) | (number);
    readonly path: Array<string>;
}
export interface ExistsFilter {
    readonly operator: "exists";
    readonly path: Array<string>;
}
export interface IsNullFilter {
    readonly operator: "isNull";
    readonly path: Array<string>;
}
export interface MatchesFilter {
    readonly operator: "matches";
    readonly pattern: string;
    readonly caseInsensitive: boolean;
    readonly path: Array<string>;
}
export interface StartsWithFilter {
    readonly operator: "startsWith";
    readonly value: string;
    readonly path: Array<string>;
}
export interface AndFilter {
    readonly operator: "and";
    readonly filters: Array<(EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter)>;
}
export interface OrFilter {
    readonly operator: "or";
    readonly filters: Array<(EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter)>;
}
export interface NotFilter {
    readonly operator: "not";
    readonly filter: (EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter);
}
export interface Order {
    readonly path: Array<string>;
    readonly direction: Direction;
}
export interface Query {
    readonly filter: (EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter);
    readonly limit?: number;
    readonly skip?: number;
    readonly orderBy?: Array<Order>;
}
export interface ClientContext {
    readonly appId: string;
    readonly appEnv: string;
    readonly collection: string;
    readonly auth: {
        v1?: {
            token: string;
        };
    };
}
export interface ServerOnlyContext {
    readonly verifiedToken?: {};
    readonly tags?: {};
    readonly logLevel?: string;
    readonly logExtra?: {};
    readonly sampleRate?: number;
    readonly debugId: string;
}
export interface UpdateOptions {
    readonly operationId?: string;
}
export interface Version {
    readonly major: number;
    readonly minor: number;
}
export interface Patch {
    readonly version: Version;
    readonly operationId?: string;
    readonly ops: Array<(AddOperation_of_any_end) | (RemoveOperation) | (ReplaceOperation_of_any_end) | (MoveOperation) | (CopyOperation) | (TestOperation_of_any_end) | (GetOperation_of_any_end)>;
}
export interface VersionedObject {
    readonly version: Version;
    readonly value: ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean));
}
export interface VersionedMaybeObject {
    readonly version: Version;
    readonly value?: ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean));
}
export interface Patches {
    readonly patches: Array<Patch>;
}
export interface StoredDocument {
    readonly updatedAt: number;
    readonly version: Version;
    readonly value: ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean));
    readonly patches: Array<Patch>;
}
export interface PollOptions {
    readonly readBlockTimeMs?: number;
}
export interface Tombstone {
    readonly updatedAt: number;
    readonly version: Version;
    readonly patches: Array<Patch>;
}
export interface DB {
    get(key: string): Promise<any>;
    getWithVersion(key: string): Promise<VersionedMaybeObject>;
    setIfVersion(key: string, version: Version, value?: ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean)), opts?: UpdateOptions): Promise<boolean>;
    startPolling(key: string): Promise<VersionedMaybeObject>;
    poll(keysToVersions: Array<[string, Version]>, opts: PollOptions): Promise<Array<[string, Array<Patch>]>>;
    create(key: string, value: ({}) | (Array<any>) | ((null) | (string) | (number) | (boolean))): Promise<boolean>;
    remove(key: string): Promise<boolean>;
    find(query: Query): Promise<Array<Document>>;
}
export interface AddOperation_of_any_end {
    readonly op: "add";
    readonly value: any;
    readonly path: string;
}
export interface RemoveOperation {
    readonly op: "remove";
    readonly path: string;
}
export interface ReplaceOperation_of_any_end {
    readonly op: "replace";
    readonly value: any;
    readonly path: string;
}
export interface MoveOperation {
    readonly op: "move";
    readonly from: string;
    readonly path: string;
}
export interface CopyOperation {
    readonly op: "copy";
    readonly from: string;
    readonly path: string;
}
export interface TestOperation_of_any_end {
    readonly op: "test";
    readonly value: any;
    readonly path: string;
}
export interface GetOperation_of_any_end {
    readonly op: "_get";
    readonly value: any;
    readonly path: string;
}
