// tslint:disable
export const schema = {
  "$schema": "http://json-schema.org/draft-07/schema#",
  "definitions": {
    "Comparable": {
      "type": [
        "string",
        "number"
      ]
    },
    "Equatable": {
      "type": [
        "string",
        "number",
        "boolean"
      ]
    },
    "Serializable": {
      "anyOf": [
        {
          "type": "object",
          "properties": {}
        },
        {
          "type": "array",
          "items": {}
        },
        {
          "type": [
            "null",
            "string",
            "number",
            "boolean"
          ]
        }
      ]
    },
    "Document": {
      "type": "object",
      "properties": {
        "key": {
          "type": "string"
        },
        "value": {
          "anyOf": [
            {
              "type": "object",
              "properties": {}
            },
            {
              "type": "array",
              "items": {}
            },
            {
              "type": [
                "null",
                "string",
                "number",
                "boolean"
              ]
            }
          ]
        }
      },
      "propertyOrder": [
        "key",
        "value"
      ],
      "required": [
        "key",
        "value"
      ]
    },
    "PathFilter": {
      "type": "object",
      "properties": {
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "path"
      ],
      "required": [
        "path"
      ]
    },
    "EqFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "eq"
          ]
        },
        "value": {
          "type": [
            "string",
            "number",
            "boolean"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "NeFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "ne"
          ]
        },
        "value": {
          "type": [
            "string",
            "number",
            "boolean"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "ComparableFilter": {
      "type": "object",
      "properties": {
        "value": {
          "type": [
            "string",
            "number"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "value",
        "path"
      ],
      "required": [
        "path",
        "value"
      ]
    },
    "GtFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "gt"
          ]
        },
        "value": {
          "type": [
            "string",
            "number"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "GteFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "gte"
          ]
        },
        "value": {
          "type": [
            "string",
            "number"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "LtFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "lt"
          ]
        },
        "value": {
          "type": [
            "string",
            "number"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "LteFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "lte"
          ]
        },
        "value": {
          "type": [
            "string",
            "number"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "ExistsFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "exists"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "path"
      ],
      "required": [
        "operator",
        "path"
      ]
    },
    "IsNullFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "isNull"
          ]
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "path"
      ],
      "required": [
        "operator",
        "path"
      ]
    },
    "MatchesFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "matches"
          ]
        },
        "pattern": {
          "type": "string"
        },
        "caseInsensitive": {
          "type": "boolean"
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "pattern",
        "caseInsensitive",
        "path"
      ],
      "required": [
        "caseInsensitive",
        "operator",
        "path",
        "pattern"
      ]
    },
    "StartsWithFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "startsWith"
          ]
        },
        "value": {
          "type": "string"
        },
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        }
      },
      "propertyOrder": [
        "operator",
        "value",
        "path"
      ],
      "required": [
        "operator",
        "path",
        "value"
      ]
    },
    "AndFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "and"
          ]
        },
        "filters": {
          "type": "array",
          "items": {
            "anyOf": [
              {
                "$ref": "#/definitions/EqFilter"
              },
              {
                "$ref": "#/definitions/NeFilter"
              },
              {
                "$ref": "#/definitions/GtFilter"
              },
              {
                "$ref": "#/definitions/GteFilter"
              },
              {
                "$ref": "#/definitions/LtFilter"
              },
              {
                "$ref": "#/definitions/LteFilter"
              },
              {
                "$ref": "#/definitions/ExistsFilter"
              },
              {
                "$ref": "#/definitions/IsNullFilter"
              },
              {
                "$ref": "#/definitions/MatchesFilter"
              },
              {
                "$ref": "#/definitions/StartsWithFilter"
              },
              {
                "$ref": "#/definitions/AndFilter"
              },
              {
                "$ref": "#/definitions/OrFilter"
              },
              {
                "$ref": "#/definitions/NotFilter"
              }
            ]
          }
        }
      },
      "propertyOrder": [
        "operator",
        "filters"
      ],
      "required": [
        "filters",
        "operator"
      ]
    },
    "OrFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "or"
          ]
        },
        "filters": {
          "type": "array",
          "items": {
            "anyOf": [
              {
                "$ref": "#/definitions/EqFilter"
              },
              {
                "$ref": "#/definitions/NeFilter"
              },
              {
                "$ref": "#/definitions/GtFilter"
              },
              {
                "$ref": "#/definitions/GteFilter"
              },
              {
                "$ref": "#/definitions/LtFilter"
              },
              {
                "$ref": "#/definitions/LteFilter"
              },
              {
                "$ref": "#/definitions/ExistsFilter"
              },
              {
                "$ref": "#/definitions/IsNullFilter"
              },
              {
                "$ref": "#/definitions/MatchesFilter"
              },
              {
                "$ref": "#/definitions/StartsWithFilter"
              },
              {
                "$ref": "#/definitions/AndFilter"
              },
              {
                "$ref": "#/definitions/OrFilter"
              },
              {
                "$ref": "#/definitions/NotFilter"
              }
            ]
          }
        }
      },
      "propertyOrder": [
        "operator",
        "filters"
      ],
      "required": [
        "filters",
        "operator"
      ]
    },
    "NotFilter": {
      "type": "object",
      "properties": {
        "operator": {
          "type": "string",
          "enum": [
            "not"
          ]
        },
        "filter": {
          "anyOf": [
            {
              "$ref": "#/definitions/EqFilter"
            },
            {
              "$ref": "#/definitions/NeFilter"
            },
            {
              "$ref": "#/definitions/GtFilter"
            },
            {
              "$ref": "#/definitions/GteFilter"
            },
            {
              "$ref": "#/definitions/LtFilter"
            },
            {
              "$ref": "#/definitions/LteFilter"
            },
            {
              "$ref": "#/definitions/ExistsFilter"
            },
            {
              "$ref": "#/definitions/IsNullFilter"
            },
            {
              "$ref": "#/definitions/MatchesFilter"
            },
            {
              "$ref": "#/definitions/StartsWithFilter"
            },
            {
              "$ref": "#/definitions/AndFilter"
            },
            {
              "$ref": "#/definitions/OrFilter"
            },
            {
              "$ref": "#/definitions/NotFilter"
            }
          ]
        }
      },
      "propertyOrder": [
        "operator",
        "filter"
      ],
      "required": [
        "filter",
        "operator"
      ]
    },
    "Filter": {
      "anyOf": [
        {
          "$ref": "#/definitions/EqFilter"
        },
        {
          "$ref": "#/definitions/NeFilter"
        },
        {
          "$ref": "#/definitions/GtFilter"
        },
        {
          "$ref": "#/definitions/GteFilter"
        },
        {
          "$ref": "#/definitions/LtFilter"
        },
        {
          "$ref": "#/definitions/LteFilter"
        },
        {
          "$ref": "#/definitions/ExistsFilter"
        },
        {
          "$ref": "#/definitions/IsNullFilter"
        },
        {
          "$ref": "#/definitions/MatchesFilter"
        },
        {
          "$ref": "#/definitions/StartsWithFilter"
        },
        {
          "$ref": "#/definitions/AndFilter"
        },
        {
          "$ref": "#/definitions/OrFilter"
        },
        {
          "$ref": "#/definitions/NotFilter"
        }
      ]
    },
    "Direction": {
      "enum": [
        "ASC",
        "DESC"
      ],
      "type": "string"
    },
    "Order": {
      "type": "object",
      "properties": {
        "path": {
          "type": "array",
          "items": {
            "type": "string"
          }
        },
        "direction": {
          "$ref": "#/definitions/Direction"
        }
      },
      "propertyOrder": [
        "path",
        "direction"
      ],
      "required": [
        "direction",
        "path"
      ]
    },
    "Query": {
      "type": "object",
      "properties": {
        "filter": {
          "anyOf": [
            {
              "$ref": "#/definitions/EqFilter"
            },
            {
              "$ref": "#/definitions/NeFilter"
            },
            {
              "$ref": "#/definitions/GtFilter"
            },
            {
              "$ref": "#/definitions/GteFilter"
            },
            {
              "$ref": "#/definitions/LtFilter"
            },
            {
              "$ref": "#/definitions/LteFilter"
            },
            {
              "$ref": "#/definitions/ExistsFilter"
            },
            {
              "$ref": "#/definitions/IsNullFilter"
            },
            {
              "$ref": "#/definitions/MatchesFilter"
            },
            {
              "$ref": "#/definitions/StartsWithFilter"
            },
            {
              "$ref": "#/definitions/AndFilter"
            },
            {
              "$ref": "#/definitions/OrFilter"
            },
            {
              "$ref": "#/definitions/NotFilter"
            }
          ]
        },
        "limit": {
          "type": "number"
        },
        "skip": {
          "type": "number"
        },
        "orderBy": {
          "type": "array",
          "items": {
            "$ref": "#/definitions/Order"
          }
        }
      },
      "propertyOrder": [
        "filter",
        "limit",
        "skip",
        "orderBy"
      ],
      "required": [
        "filter"
      ]
    },
    "ClientContext": {
      "type": "object",
      "properties": {
        "appId": {
          "type": "string"
        },
        "appEnv": {
          "type": "string"
        },
        "collection": {
          "type": "string"
        },
        "auth": {
          "type": "object",
          "properties": {
            "v1": {
              "type": "object",
              "properties": {
                "token": {
                  "type": "string"
                }
              },
              "propertyOrder": [
                "token"
              ],
              "required": [
                "token"
              ]
            }
          },
          "propertyOrder": [
            "v1"
          ]
        }
      },
      "propertyOrder": [
        "appId",
        "appEnv",
        "collection",
        "auth"
      ],
      "required": [
        "appEnv",
        "appId",
        "auth",
        "collection"
      ]
    },
    "ServerOnlyContext": {
      "type": "object",
      "properties": {
        "verifiedToken": {
          "type": "object",
          "properties": {},
          "additionalProperties": true
        },
        "tags": {
          "type": "object",
          "additionalProperties": {
            "type": "string"
          },
          "propertyOrder": []
        },
        "logLevel": {
          "type": "string"
        },
        "logExtra": {
          "type": "object",
          "additionalProperties": {},
          "propertyOrder": []
        },
        "sampleRate": {
          "type": "number"
        },
        "debugId": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "verifiedToken",
        "tags",
        "logLevel",
        "logExtra",
        "sampleRate",
        "debugId"
      ],
      "required": [
        "debugId"
      ]
    },
    "UpdateOptions": {
      "type": "object",
      "properties": {
        "operationId": {
          "description": "Used to mark an update originated from a specific operation (useful for optimistic UI).\nThis is meant to be UUID generated by the client.",
          "type": "string"
        }
      },
      "propertyOrder": [
        "operationId"
      ]
    },
    "Version": {
      "type": "object",
      "properties": {
        "major": {
          "type": "number"
        },
        "minor": {
          "type": "number"
        }
      },
      "propertyOrder": [
        "major",
        "minor"
      ],
      "required": [
        "major",
        "minor"
      ]
    },
    "Patch": {
      "type": "object",
      "properties": {
        "version": {
          "$ref": "#/definitions/Version"
        },
        "operationId": {
          "description": "Used to mark an update originated from a specific operation (useful for optimistic UI).",
          "type": "string"
        },
        "ops": {
          "type": "array",
          "items": {
            "anyOf": [
              {
                "$ref": "#/definitions/AddOperation<any>"
              },
              {
                "$ref": "#/definitions/RemoveOperation"
              },
              {
                "$ref": "#/definitions/ReplaceOperation<any>"
              },
              {
                "$ref": "#/definitions/MoveOperation"
              },
              {
                "$ref": "#/definitions/CopyOperation"
              },
              {
                "$ref": "#/definitions/TestOperation<any>"
              },
              {
                "$ref": "#/definitions/GetOperation<any>"
              }
            ]
          }
        }
      },
      "propertyOrder": [
        "version",
        "operationId",
        "ops"
      ],
      "required": [
        "ops",
        "version"
      ]
    },
    "KeyedPatches": {
      "type": "array",
      "items": {
        "type": "array",
        "items": [
          {
            "type": "string"
          },
          {
            "type": "array",
            "items": {
              "$ref": "#/definitions/Patch"
            }
          }
        ],
        "minItems": 2,
        "additionalItems": {
          "anyOf": [
            {
              "type": "string"
            },
            {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Patch"
              }
            }
          ]
        }
      }
    },
    "VersionedObject": {
      "type": "object",
      "properties": {
        "version": {
          "$ref": "#/definitions/Version"
        },
        "value": {
          "anyOf": [
            {
              "type": "object",
              "properties": {}
            },
            {
              "type": "array",
              "items": {}
            },
            {
              "type": [
                "null",
                "string",
                "number",
                "boolean"
              ]
            }
          ]
        }
      },
      "propertyOrder": [
        "version",
        "value"
      ],
      "required": [
        "value",
        "version"
      ]
    },
    "VersionedMaybeObject": {
      "type": "object",
      "properties": {
        "version": {
          "$ref": "#/definitions/Version"
        },
        "value": {
          "anyOf": [
            {
              "type": "object",
              "properties": {}
            },
            {
              "type": "array",
              "items": {}
            },
            {
              "type": [
                "null",
                "string",
                "number",
                "boolean"
              ]
            }
          ]
        }
      },
      "propertyOrder": [
        "version",
        "value"
      ],
      "required": [
        "version"
      ]
    },
    "Patches": {
      "type": "object",
      "properties": {
        "patches": {
          "description": "Stores changes made to the document, meant to be used internally by poll().",
          "type": "array",
          "items": {
            "$ref": "#/definitions/Patch"
          }
        }
      },
      "propertyOrder": [
        "patches"
      ],
      "required": [
        "patches"
      ]
    },
    "KeyedVersions": {
      "type": "array",
      "items": {
        "type": "array",
        "items": [
          {
            "type": "string"
          },
          {
            "$ref": "#/definitions/Version"
          }
        ],
        "minItems": 2,
        "additionalItems": {
          "anyOf": [
            {
              "type": "string"
            },
            {
              "$ref": "#/definitions/Version"
            }
          ]
        }
      }
    },
    "StoredDocument": {
      "type": "object",
      "properties": {
        "updatedAt": {
          "type": "number"
        },
        "version": {
          "$ref": "#/definitions/Version"
        },
        "value": {
          "anyOf": [
            {
              "type": "object",
              "properties": {}
            },
            {
              "type": "array",
              "items": {}
            },
            {
              "type": [
                "null",
                "string",
                "number",
                "boolean"
              ]
            }
          ]
        },
        "patches": {
          "description": "Stores changes made to the document, meant to be used internally by poll().",
          "type": "array",
          "items": {
            "$ref": "#/definitions/Patch"
          }
        }
      },
      "propertyOrder": [
        "updatedAt",
        "version",
        "value",
        "patches"
      ],
      "required": [
        "patches",
        "updatedAt",
        "value",
        "version"
      ]
    },
    "PollOptions": {
      "type": "object",
      "properties": {
        "readBlockTimeMs": {
          "type": "number"
        }
      },
      "propertyOrder": [
        "readBlockTimeMs"
      ]
    },
    "Tombstone": {
      "description": "A deleted document in the database, used for updating and for\nstreaming.",
      "type": "object",
      "properties": {
        "updatedAt": {
          "type": "number"
        },
        "version": {
          "$ref": "#/definitions/Version"
        },
        "patches": {
          "description": "Stores changes made to the document, meant to be used internally by poll().",
          "type": "array",
          "items": {
            "$ref": "#/definitions/Patch"
          }
        }
      },
      "propertyOrder": [
        "updatedAt",
        "version",
        "patches"
      ],
      "required": [
        "patches",
        "updatedAt",
        "version"
      ]
    },
    "DB": {
      "type": "object",
      "properties": {
        "get": {
          "description": "Gets a single document.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "key": {
                  "type": "string"
                }
              },
              "propertyOrder": [
                "key"
              ],
              "required": [
                "key"
              ]
            },
            "returns": {}
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "getWithVersion": {
          "description": "Gets a single document and its version.  First half of an update cycle.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "key": {
                  "type": "string"
                }
              },
              "propertyOrder": [
                "key"
              ],
              "required": [
                "key"
              ]
            },
            "returns": {
              "$ref": "#/definitions/VersionedMaybeObject"
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "setIfVersion": {
          "description": "Updates document at key if version matches.  Second half of an update cycle.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "key": {
                  "type": "string"
                },
                "version": {
                  "$ref": "#/definitions/Version"
                },
                "value": {
                  "anyOf": [
                    {
                      "type": "object",
                      "properties": {}
                    },
                    {
                      "type": "array",
                      "items": {}
                    },
                    {
                      "type": [
                        "null",
                        "string",
                        "number",
                        "boolean"
                      ]
                    }
                  ]
                },
                "opts": {
                  "$ref": "#/definitions/UpdateOptions"
                }
              },
              "propertyOrder": [
                "key",
                "version",
                "value",
                "opts"
              ],
              "required": [
                "key",
                "version"
              ]
            },
            "returns": {
              "type": "boolean"
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "startPolling": {
          "description": "Gets a initial document in an intent to for poll on it.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "key": {
                  "type": "string"
                }
              },
              "propertyOrder": [
                "key"
              ],
              "required": [
                "key"
              ]
            },
            "returns": {
              "$ref": "#/definitions/VersionedMaybeObject"
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "poll": {
          "description": "Polls on updates to specified keys since specified versions.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "keysToVersions": {
                  "type": "array",
                  "items": {
                    "type": "array",
                    "items": [
                      {
                        "type": "string"
                      },
                      {
                        "$ref": "#/definitions/Version"
                      }
                    ],
                    "minItems": 2,
                    "additionalItems": {
                      "anyOf": [
                        {
                          "type": "string"
                        },
                        {
                          "$ref": "#/definitions/Version"
                        }
                      ]
                    }
                  }
                },
                "opts": {
                  "$ref": "#/definitions/PollOptions"
                }
              },
              "propertyOrder": [
                "keysToVersions",
                "opts"
              ],
              "required": [
                "keysToVersions",
                "opts"
              ]
            },
            "returns": {
              "type": "array",
              "items": {
                "type": "array",
                "items": [
                  {
                    "type": "string"
                  },
                  {
                    "type": "array",
                    "items": {
                      "$ref": "#/definitions/Patch"
                    }
                  }
                ],
                "minItems": 2,
                "additionalItems": {
                  "anyOf": [
                    {
                      "type": "string"
                    },
                    {
                      "type": "array",
                      "items": {
                        "$ref": "#/definitions/Patch"
                      }
                    }
                  ]
                }
              }
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "create": {
          "description": "Creates a document for a given key.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "key": {
                  "type": "string"
                },
                "value": {
                  "anyOf": [
                    {
                      "type": "object",
                      "properties": {}
                    },
                    {
                      "type": "array",
                      "items": {}
                    },
                    {
                      "type": [
                        "null",
                        "string",
                        "number",
                        "boolean"
                      ]
                    }
                  ]
                }
              },
              "propertyOrder": [
                "key",
                "value"
              ],
              "required": [
                "key",
                "value"
              ]
            },
            "returns": {
              "type": "boolean"
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "remove": {
          "description": "Removes the document at key.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "key": {
                  "type": "string"
                }
              },
              "propertyOrder": [
                "key"
              ],
              "required": [
                "key"
              ]
            },
            "returns": {
              "type": "boolean"
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        },
        "find": {
          "description": "Find documents matching query.",
          "type": "object",
          "properties": {
            "params": {
              "type": "object",
              "properties": {
                "query": {
                  "$ref": "#/definitions/Query"
                }
              },
              "propertyOrder": [
                "query"
              ],
              "required": [
                "query"
              ]
            },
            "returns": {
              "type": "array",
              "items": {
                "$ref": "#/definitions/Document"
              }
            }
          },
          "propertyOrder": [
            "params",
            "returns"
          ],
          "required": [
            "params",
            "returns"
          ]
        }
      },
      "propertyOrder": [
        "get",
        "getWithVersion",
        "setIfVersion",
        "startPolling",
        "poll",
        "create",
        "remove",
        "find"
      ],
      "required": [
        "create",
        "find",
        "get",
        "getWithVersion",
        "poll",
        "remove",
        "setIfVersion",
        "startPolling"
      ]
    },
    "AddOperation<any>": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "add"
          ]
        },
        "value": {},
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "value",
        "path"
      ],
      "required": [
        "op",
        "path",
        "value"
      ]
    },
    "RemoveOperation": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "remove"
          ]
        },
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "path"
      ],
      "required": [
        "op",
        "path"
      ]
    },
    "ReplaceOperation<any>": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "replace"
          ]
        },
        "value": {},
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "value",
        "path"
      ],
      "required": [
        "op",
        "path",
        "value"
      ]
    },
    "MoveOperation": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "move"
          ]
        },
        "from": {
          "type": "string"
        },
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "from",
        "path"
      ],
      "required": [
        "from",
        "op",
        "path"
      ]
    },
    "CopyOperation": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "copy"
          ]
        },
        "from": {
          "type": "string"
        },
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "from",
        "path"
      ],
      "required": [
        "from",
        "op",
        "path"
      ]
    },
    "TestOperation<any>": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "test"
          ]
        },
        "value": {},
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "value",
        "path"
      ],
      "required": [
        "op",
        "path",
        "value"
      ]
    },
    "GetOperation<any>": {
      "type": "object",
      "properties": {
        "op": {
          "type": "string",
          "enum": [
            "_get"
          ]
        },
        "value": {},
        "path": {
          "type": "string"
        }
      },
      "propertyOrder": [
        "op",
        "value",
        "path"
      ],
      "required": [
        "op",
        "path",
        "value"
      ]
    }
  }
};

export class InternalServerError extends Error {
  public readonly name = 'InternalServerError';
}

export enum Direction {
  ASC = 'ASC',
  DESC = 'DESC',
}

export type Serializable = ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean));

export type Filter = (EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter);

export interface Document {
  readonly key: string;
  readonly value: ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean));
}

export interface PathFilter {
  readonly path: Array<string>;
}

export interface EqFilter {
  readonly operator: "eq";
  readonly value: (string) | (number) | (boolean);
  readonly path: Array<string>;
}

export interface NeFilter {
  readonly operator: "ne";
  readonly value: (string) | (number) | (boolean);
  readonly path: Array<string>;
}

export interface ComparableFilter {
  readonly value: (string) | (number);
  readonly path: Array<string>;
}

export interface GtFilter {
  readonly operator: "gt";
  readonly value: (string) | (number);
  readonly path: Array<string>;
}

export interface GteFilter {
  readonly operator: "gte";
  readonly value: (string) | (number);
  readonly path: Array<string>;
}

export interface LtFilter {
  readonly operator: "lt";
  readonly value: (string) | (number);
  readonly path: Array<string>;
}

export interface LteFilter {
  readonly operator: "lte";
  readonly value: (string) | (number);
  readonly path: Array<string>;
}

export interface ExistsFilter {
  readonly operator: "exists";
  readonly path: Array<string>;
}

export interface IsNullFilter {
  readonly operator: "isNull";
  readonly path: Array<string>;
}

export interface MatchesFilter {
  readonly operator: "matches";
  readonly pattern: string;
  readonly caseInsensitive: boolean;
  readonly path: Array<string>;
}

export interface StartsWithFilter {
  readonly operator: "startsWith";
  readonly value: string;
  readonly path: Array<string>;
}

export interface AndFilter {
  readonly operator: "and";
  readonly filters: Array<(EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter)>;
}

export interface OrFilter {
  readonly operator: "or";
  readonly filters: Array<(EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter)>;
}

export interface NotFilter {
  readonly operator: "not";
  readonly filter: (EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter);
}

export interface Order {
  readonly path: Array<string>;
  readonly direction: Direction;
}

export interface Query {
  readonly filter: (EqFilter) | (NeFilter) | (GtFilter) | (GteFilter) | (LtFilter) | (LteFilter) | (ExistsFilter) | (IsNullFilter) | (MatchesFilter) | (StartsWithFilter) | (AndFilter) | (OrFilter) | (NotFilter);
  readonly limit?: number;
  readonly skip?: number;
  readonly orderBy?: Array<Order>;
}

export interface ClientContext {
  readonly appId: string;
  readonly appEnv: string;
  readonly collection: string;
  readonly auth: { v1?: { token: string; }; };
}

export interface ServerOnlyContext {
  readonly verifiedToken?: {  };
  readonly tags?: {};
  readonly logLevel?: string;
  readonly logExtra?: {};
  readonly sampleRate?: number;
  readonly debugId: string;
}

export interface UpdateOptions {
  readonly operationId?: string;
}

export interface Version {
  readonly major: number;
  readonly minor: number;
}

export interface Patch {
  readonly version: Version;
  readonly operationId?: string;
  readonly ops: Array<(AddOperation_of_any_end) | (RemoveOperation) | (ReplaceOperation_of_any_end) | (MoveOperation) | (CopyOperation) | (TestOperation_of_any_end) | (GetOperation_of_any_end)>;
}

export interface VersionedObject {
  readonly version: Version;
  readonly value: ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean));
}

export interface VersionedMaybeObject {
  readonly version: Version;
  readonly value?: ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean));
}

export interface Patches {
  readonly patches: Array<Patch>;
}

export interface StoredDocument {
  readonly updatedAt: number;
  readonly version: Version;
  readonly value: ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean));
  readonly patches: Array<Patch>;
}

export interface PollOptions {
  readonly readBlockTimeMs?: number;
}

export interface Tombstone {
  readonly updatedAt: number;
  readonly version: Version;
  readonly patches: Array<Patch>;
}

export interface DB {
  get(key: string): Promise<any>;
  getWithVersion(key: string): Promise<VersionedMaybeObject>;
  setIfVersion(key: string, version: Version, value?: ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean)), opts?: UpdateOptions): Promise<boolean>;
  startPolling(key: string): Promise<VersionedMaybeObject>;
  poll(keysToVersions: Array<[string, Version]>, opts: PollOptions): Promise<Array<[string, Array<Patch>]>>;
  create(key: string, value: ({  }) | (Array<any>) | ((null) | (string) | (number) | (boolean))): Promise<boolean>;
  remove(key: string): Promise<boolean>;
  find(query: Query): Promise<Array<Document>>;
}

export interface AddOperation_of_any_end {
  readonly op: "add";
  readonly value: any;
  readonly path: string;
}

export interface RemoveOperation {
  readonly op: "remove";
  readonly path: string;
}

export interface ReplaceOperation_of_any_end {
  readonly op: "replace";
  readonly value: any;
  readonly path: string;
}

export interface MoveOperation {
  readonly op: "move";
  readonly from: string;
  readonly path: string;
}

export interface CopyOperation {
  readonly op: "copy";
  readonly from: string;
  readonly path: string;
}

export interface TestOperation_of_any_end {
  readonly op: "test";
  readonly value: any;
  readonly path: string;
}

export interface GetOperation_of_any_end {
  readonly op: "_get";
  readonly value: any;
  readonly path: string;
}

